@@ -101,6 +101,14 @@ var addOperatorScenarios = []expressionScenario{
 			"D0, P[], (doc)::a: ['dog', 'cat']\n",
 		},
 	},
+	{
+		description: "Prepend to existing array",
+		document:    `a: [dog]`,
+		expression:  `.a = ["cat"] + .a`,
+		expected: []string{
+			"D0, P[], (doc)::a: [cat, dog]\n",
+		},
+	},
 	{
 		skipDoc:        true,
 		description:    "Concatenate to existing array",
